@@ -12,10 +12,10 @@ from . import BaseGarden
 
 def adapt_bytea(obj):
     '''Adapt an object to a bytea by pickling.'''
-    if isinstance(key, str):
+    if isinstance(obj, str):
         # Convert strings to unicodes when possible
         try:
-            obj = unicode(key)
+            obj = unicode(obj)
         except UnicodeDecodeError:
             pass
     p = pickle.dumps(obj, pickle.HIGHEST_PROTOCOL)
